setwd("/data/sPlot/users/Helge/HIDDEN")
library(tidyverse)
library(foreign)
library(gridExtra)
library(grid)
library(vegan)



source("99_HIDDEN_functions.R")

##### PART 1 ####
#### 1. traits data  #### 

traits0 <- read_delim("_data/Mesobromion/traits4.csv", delim =",",  ## manually corrected vowels with umlaut
                      col_names = T, locale = locale(encoding = 'UTF-8')) %>% 
  column_to_rownames("X1") %>% 
  dplyr::select(-starts_with("X")) %>% 
  dplyr::select(colnames(.)[which(colSums(., na.rm=T)!=0)]) %>% 
  dplyr::select(!starts_with("BLM")) %>% 
  dplyr::select(!starts_with("ZWT")) %>% 
  dplyr::select(!starts_with("Fabaceae")) %>% 
  dplyr::select(!starts_with("BEST_")) %>% 
  dplyr::select(!ends_with("1")) %>% 
  dplyr::select(- any_of(c("PR_STAT_Indigen", "PR_STAT_Neophyt", "PR_STAT_Archaeophyt", "URBAN_urbanophob", "URBAN_maessig_urbanophob", 
                    "URBAN_urbanoneutral", "URBAN_maessig_urbanophil", "URBAN_urbanophil", "WUH_von", "WUH_bis", "ARL_c_I_von", "ARL_c_I_bis", 
                    "BL_ANAT_hydromorph", "WEID_V", "MAHD_V", "TRIT_V"))) %>%  #empty trait
  rownames_to_column("species") %>% 
  mutate(species0=species) %>% 
  rowwise() %>% 
  # quick and dirty clean up names
  mutate(species=gsub(pattern="_", replacement = " ", x = species)) %>% 
  mutate(species=gsub(pattern=" agg | x | spec$| agg$| s | Sec |  ", replacement=" ", x=species)) %>% 
  mutate(species=gsub(pattern=" $", replacement = "", x = species)) %>% 
  mutate(species=ifelse(is.na(word(species, 1, 2)), species, word(species, 1, 2))) %>% 
  ungroup()
dim(traits0) #902 obs. of  65 variables:

## remove species with NAs
species.to.remove <- traits0 %>%  
  filter(all_of(is.na({.} %>% dplyr::select(-species, -species0)))) %>% 
  pull(species0)
traits0 <- traits0 %>% 
  filter(!species0 %in% species.to.remove)
  

# #keep only traits with >=88 completeness
# traits0 <- traits0 %>% 
#   dplyr::select_if(~mean(!is.na(.)) >= 0.88) 
# dim(traits0)# 902 x 67




### Transform binary traits to 0-1
traits.asym.binary <- c('LEB_F_Makrophanerophyt','LEB_F_Nanophanerophyt',
                        'LEB_F_Hemikryptophyt','LEB_F_Geophyt','LEB_F_Hemiphanerophyt','LEB_F_Therophyt',
                        'LEB_F_Hydrophyt','LEB_F_Pseudophanerophyt','LEB_F_Chamaephyt',
                        'LEB_D_plurienn_pollakanth','LBE_D_plurienn_hapaxanth','LEB_D_annuell',
                        'LEB_D_bienn','V_VER_absent','V_VER_Wurzelspross','V_VER_Ausläufer',
                        'V_VER_Rhizom','V_VER_Innovationsknopse.mit.Wurzelknolle',
                        'V_VER_Innovationsknospe.mit.Speicherwurzel','V_VER_Ausläuferknolle',
                        'V_VER_Brutsprösschen','V_VER_Fragmentation','V_VER_Turio','V_VER_Sprossknolle',
                        'V_VER_phyllogener_Spross','V_VER_Rhizompleiokorm','V_VER_Zwiebel',
                        'V_VER_Ausläuferrhizom',#'V_VER_Ausläuferzwiebel',
                        'V_VER_Bulbille',
                        'ROS_T_rosettenlose.Pflanzen','ROS_T_Halbrosettenpflanze','ROS_T_Ganzrosettenpflanzen',
                        'BL_AUSD_immergrün','BL_AUSD_sommergrün','BL_AUSD_vorsommergrün',
                        'BL_AUSD_überwinternd_grün','BL_ANAT_skleromorph','BL_ANAT_mesomorph',
                        'BL_ANAT_hygromorph',#'BL_ANAT_hydromorph',
                        'BL_ANAT_blattsukkulent','BL_ANAT_helomorph',
                        'BL_FORM_gelappt_gefiedert_gefingert_mehrfach','BL_FORM_Vollblatt_Normalblatt',
                        'BL_FORM_Grasblatt_Langblatt','BL_FORM_nadelförmig','BL_FORM_röhrig',
                        'BL_FORM_schuppenförmig','BL_FORM_schwertförmig','REPR_T_Samen_Sporen',
                        'REPR_T_vegetativ','BLU_KL_WIND','BLU_KL_POLLEN',
                        'BLU_KL_NEKTAR_HONIG_INSEKTEN','STRAT_T_C','STRAT_T_CR','STRAT_T_CS',
                        'STRAT_T_CSR','STRAT_T_R','STRAT_T_S','STRAT_T_SR')

traits0 <- traits0 %>% 
  mutate_at(.vars=vars(all_of(traits.asym.binary)), 
            .funs=~(.>0)*1)


## Import traits from TRY and match to species
load("/data/sPlot2.0/TRY.all.mean.sd.3.by.genus.species.tree.Rdata")
alltry <- TRY.all.mean.sd.3.by.genus.species.tree %>% 
  dplyr::select(!ends_with(".sd")) %>% 
  dplyr::select(StandSpeciesName, LeafArea.mean:Wood.vessel.length.mean) %>% 
  dplyr::select(-Wood.vessel.length.mean, -StemDens.mean, -Stem.cond.dens.mean) %>% 
  rename_all(.funs=~gsub(pattern=".mean$", replacement="", x=.))

all.traits <- traits0 %>% 
  ungroup() %>% 
  #dplyr::select(species, species0) %>% 
  left_join(alltry %>% 
              rename(species=StandSpeciesName), 
            by="species") 
traits <- all.traits %>% 
  filter(!is.na(LeafArea))
dim(all.traits) #[1] 898  80
dim(traits) #[1] 799  80



##### 2. Header Data #### 
env0 <- read_delim("_data/Mesobromion/GVRD_MES2_site.csv", delim = ",")
str(env0) #6868 obs. of  6 variables:

set.seed(1984)
header   <- "/data/sPlot/users/Francesco/Project_11/Germany/_data/tvhabita.dbf"
env  <- env0 %>% 
  left_join(foreign::read.dbf(header) %>% 
              as.data.frame() %>% 
              dplyr::select(RELEVE_NR, LAT, LON),
            by="RELEVE_NR") %>% 
  filter(!is.na(LAT)) %>%
  filter(!(LAT==0 | LON==0)) 

env.all <- env



### 3. Import species data #### 
# columns in species correspond to those in env
# there is no PlotObservationID (yet)
species0 <- read_csv("_data/Mesobromion/GVRD_Mes2_proz2.csv", locale = locale(encoding = 'latin1')) %>% 
  dplyr::select(-species.to.remove) %>% 
  mutate(RELEVE_NR=env0$RELEVE_NR)
dim(species0) #6868 obs. of  899 variables:


## select only plots already selected in env
species <- env %>% 
  dplyr::select(RELEVE_NR) %>% 
  left_join(species0,
            by="RELEVE_NR") %>% 
  column_to_rownames("RELEVE_NR") %>% 
  ## delete species not appearing in any plot
  dplyr::select(colnames(.)[which(colSums(.)!=0)])
#dplyr::select(traits$species0)

dim(species) # [1] 5810 873
### 3.1 Subset plots based on trait coverage ####
releve08trait <- species %>% 
  rownames_to_column("RELEVE_NR") %>% 
  reshape2::melt(.id="RELEVE_NR") %>% 
  rename(species0=variable, perc.cover=value) %>% 
  as.tbl() %>% 
  filter(perc.cover>0) %>% 
  arrange(RELEVE_NR)  %>% 
  ## attach traits 
  left_join(traits %>% 
              dplyr::select(-species), by="species0") %>% 
  mutate_at(.vars = vars(LEB_F_Makrophanerophyt:Disp.unit.leng), 
            .funs = list(~if_else(is.na(.),0,1) * perc.cover)) %>%
  group_by(RELEVE_NR) %>%
  summarize_at(.vars= vars(LEB_F_Makrophanerophyt:Disp.unit.leng),
               .funs = list(~sum(.)/sum(perc.cover))) %>%
  dplyr::select(RELEVE_NR, order(colnames(.))) %>%
  reshape2::melt(id.vars="RELEVE_NR", value.name="trait.coverage") %>% 
  group_by(RELEVE_NR) %>% 
  summarize(ntraits08=mean(trait.coverage>=0.8)) %>% 
  #select only those releves where we have a coverage of >0.8 for all traits
  filter(ntraits08==1) %>% 
  pull(RELEVE_NR)
length(releve08trait) #[1] 5646

set.seed(1984)
releve08trait.samp <- sample(releve08trait, round(length(releve08trait)/10), replace=F)
species <- species %>% 
  rownames_to_column("RELEVE_NR") %>% 
  filter(RELEVE_NR %in% releve08trait.samp) %>% 
  #as.tbl() %>% 
  dplyr::select(RELEVE_NR, one_of(traits$species0)) %>% 
  column_to_rownames("RELEVE_NR") %>% 
  dplyr::select(colnames(.)[which(colSums(.)!=0)])

env <- env %>% 
  filter(RELEVE_NR %in% releve08trait.samp)

traits <- traits %>% 
  dplyr::select(-species) %>% 
  dplyr::select(species0, everything()) %>% 
  filter(species0 %in% colnames(species))


recode.traits <- function(x){
  ## recode traits to numeric
  #recode binary traits to nominal
  
  robust.mean <- function(x1,x2=NA,x3=NA,x4=NA){
    x <- c(x1,x2,x3,x4)
    if(any(!is.na(x))){mean(x, na.rm=T)} else {NA}
  }
  colnames(x)[which(colnames(x)=="LBE_D_plurienn_hapaxanth")] <- "LEB_D_plurienn_hapaxanth"
  x <- x %>% 
    mutate(BLU_KL_NEKTAR_HONIG_INSEKTEN=replace(BLU_KL_NEKTAR_HONIG_INSEKTEN, 
                                                list=species0 %in% c("Convallaria_majalis", "Maianthemum_bifolium"),
                                                values=0))
  
  x <- x %>% 
    as.tbl() %>% 
    dplyr::select(-starts_with("BL_FORM"), -starts_with("REPR_T"), -starts_with("BLU_KL"), -starts_with("STRAT_T"), -starts_with("BL_AUSD")) %>% 
    left_join(x %>% 
                dplyr::select(species0, `BL_AUSD_immergrün`:`BL_AUSD_überwinternd_grün`, REPR_T_Samen_Sporen:STRAT_T_SR) %>% 
                gather(key=Trait, value="value", -species0) %>% 
                separate(Trait, into = c("Trait", "Organ", "Level"), sep = "_", extra = "merge") %>% 
                unite(Trait, Trait, Organ) %>% 
                filter(value==1) %>% 
                dplyr::select(-value) %>% 
                spread(Trait, Level) %>% 
                mutate_at(.vars=vars(BL_AUSD:STRAT_T), 
                          .funs=~as.factor(.)), 
              by="species0")
  
  out <- x %>% 
    dplyr::select(-starts_with("BL_ANAT"), -starts_with("LEB_D"), -starts_with("ROS_T")) %>% 
    left_join(x %>% 
                dplyr::select(species0, starts_with("BL_ANAT")) %>% 
                mutate(BL_ANAT_helomorph=ifelse(BL_ANAT_helomorph==1, 1, NA)) %>% 
                mutate(BL_ANAT_hygromorph=ifelse(BL_ANAT_hygromorph==1, 2, NA)) %>% 
                mutate(BL_ANAT_mesomorph=ifelse(BL_ANAT_mesomorph==1, 3, NA)) %>% 
                mutate(BL_ANAT_skleromorph=ifelse(BL_ANAT_skleromorph==1, 4, NA)) %>% 
                rowwise() %>% 
                mutate(BL_ANAT=robust.mean(BL_ANAT_helomorph, BL_ANAT_hygromorph, BL_ANAT_mesomorph, BL_ANAT_skleromorph)) %>% 
                ungroup() %>% 
                dplyr::select(species0, BL_ANAT, BL_ANAT_blattsukkulent), 
              by="species0") %>% 
    left_join(x %>% 
                dplyr::select(species0, starts_with("LEB_D"))  %>%
                rowwise() %>% 
                mutate(LEB_D_plurienn=max(LEB_D_plurienn_pollakanth + LEB_D_plurienn_hapaxanth, na.rm=T)) %>% 
                ungroup() %>% 
                mutate(LEB_D_plurienn=ifelse(LEB_D_plurienn==1, 3, NA)) %>% 
                mutate(LEB_D_annuell=ifelse(LEB_D_annuell==1, 1, NA)) %>% 
                mutate(LEB_D_bienn =ifelse(LEB_D_bienn==1, 2, NA)) %>% 
                rowwise() %>% 
                mutate(LEB_D=robust.mean(LEB_D_annuell, LEB_D_bienn, LEB_D_plurienn)) %>% 
                ungroup() %>% 
                dplyr::select(species0, LEB_D), 
              by="species0") %>% 
    left_join(x %>% 
                dplyr::select(species0, starts_with("ROS_T")) %>% 
                mutate(ROS_T=ROS_T_Ganzrosettenpflanzen) %>% 
                mutate(ROS_T=replace(ROS_T, 
                                     list=ROS_T_Halbrosettenpflanze==1, 
                                     values=0.5)) %>% 
                mutate(ROS_T=replace(ROS_T, 
                                     list=ROS_T_rosettenlose.Pflanzen==1, 
                                     values=0)) %>% 
                dplyr::select(species0, ROS_T), 
              by="species0") 
  return(out)
}
traits <- recode.traits(traits)

### Some cleaning and renaming of traits; exclude CSR - decisions 25.08.2020
traits <- traits %>% 
  dplyr::select(-STRAT_T) %>% 
  mutate(REPR_T=factor(REPR_T, levels=c("Samen_Sporen","vegetativ"), 
                       labels=c("Seed/Spores", "Vegetative"))) %>% 
  mutate(BLU_KL=factor(BLU_KL, levels=c("NEKTAR_HONIG_INSEKTEN","POLLEN", "WIND"), 
                       labels=c("Nectar/Honey/Insects", "Pollen", "Wind"))) %>% 
  mutate(BL_AUSD = factor(BL_AUSD, 
                          levels=c("immergrün","sommergrün","überwinternd_grün", "vorsommergrün"),
                          labels=c("eg", "sg", "wg", "se")))

##rename traits based on labels
trait.labs <- data.frame(trait.name=colnames(traits)[-1]) %>% 
  left_join(read_delim("_data/Mesobromion/TraitLabels_Long.csv", delim=","), 
            by="trait.name") %>% 
  rownames_to_column("Trait.comb") %>% 
  mutate_at(.vars=vars(Short_english_name:Long_English_name), ~ifelse(is.na(.), trait.name, {.})) %>% 
  filter(trait.name %in% colnames(traits))

traits <- traits %>% 
  rename_at(trait.labs$trait.name, .funs=function(x) trait.labs$Short_english_name)

##exclude traits being all == 0
traits <- traits %>% 
  dplyr::select(-colnames(.)[which(colSums(.!=0)==0)]) 


dim(species) #565 488
dim(traits) #488 50
dim(env) #565 8




######4.  Extract Environmental Factors ######
### CHELSA
library(raster)
library(sp)
Temp <- raster("../../Francesco/Ancillary_Data/CHELSA/CHELSA_bio10_01.tif")
Prec <- raster("../../Francesco/Ancillary_Data/CHELSA/CHELSA_bio10_12.tif")
PHIPHOX <- raster("../../Francesco/Ancillary_Data/ISRIC/PHIHOX_M_sl2_250m_ll.tif")
ORCDRC <- raster("../../Francesco/Ancillary_Data/ISRIC/ORCDRC_M_sl2_250m_ll.tif")


env.sp <- SpatialPointsDataFrame(coords=env %>% dplyr::select(LON, LAT), 
                                 data=env %>% dplyr::select(-LON, -LAT), 
                                 proj4string = raster::crs("+proj=longlat +datum=WGS84 +no_defs")) 
env <- env %>% 
  mutate(Temp=raster::extract(Temp, env.sp)/10) %>% 
  mutate(Prec=raster::extract(Prec, env.sp)) %>% 
  mutate(PHIPHOX=raster::extract(PHIPHOX, env.sp)/10) %>% 
  mutate(ORCDRC=raster::extract(ORCDRC, env.sp)) 



## Select only plots where >90% of species have trait info [TRY]
# releve08trait <- species %>% 
#   rownames_to_column("RELEVE_NR") %>% 
#   reshape2::melt(.id="RELEVE_NR") %>% 
#   rename(species0=variable, pres=value) %>% 
#   filter(pres>0) %>% 
#   arrange(RELEVE_NR)  %>% 
#   ## attach traits 
#   left_join(traits %>% 
#               dplyr::select(-species, LeafArea.mean), by="species0") %>% 
#   group_by(RELEVE_NR) %>% 
#   summarize(trait.coverage=mean(!is.na(LeafArea.mean))) %>% 
#   filter(trait.coverage<0.8) %>% 
#   pull(RELEVE_NR)
# 

species <- species %>% 
  rownames_to_column("RELEVE_NR")

###### 5. Transform and export data  ######

## presence absence
species.pa <- species
species.pa[,-1] <- (species[,-1]>0)*1
## sqrt transform cov values
species.cov <- species
species.cov[,-1] <- sqrt(species.cov[,-1])
#transform percentage cover to relative.cover
species.cov <- species.cov %>% 
  mutate(sumVar = rowSums(.[-1])) %>% 
  mutate_at(.vars=vars(-RELEVE_NR), 
            .funs=~./sumVar) %>% 
  dplyr::select(-sumVar) 
dim(species.cov) #[1] 565 489

## export
write_delim(species, path="_data/Mesobromion/species.v2.10perc.percentage.txt", delim="\t") ## original covere values
write_delim(species.pa, path="_data/Mesobromion/species.v2.10perc.pa.txt", delim="\t")
write_delim(species.cov, path="_data/Mesobromion/species.v2.10perc.cov.txt", delim="\t")
write_delim(traits, path="_data/Mesobromion/traits.v2.10perc.txt", delim="\t")
write_delim(env, path="_data/Mesobromion/env.v2.10perc.cov.txt", delim="\t")

### create list of relevées
write_delim(species %>% 
              dplyr::select(RELEVE_NR), 
            path="_output/S10_ReleveList.txt", delim="\t")


##check for species without trait info
traits %>% 
  filter_at(.vars=vars(-"species0"), 
            all_vars(is.na(.))) %>% 
  nrow() ## [1] no species with no trait info ##

traits %>% 
  filter_at(.vars=vars(-"species0"), 
            any_vars(is.na(.))) %>% 
  nrow() ## [1] 47 # species with at least 1 NA in traits


#### CORRELATION BETWEEN FUZZY WEIGHTED AND BEALS MATRICES
#### WAS RUN IN THE CLUSTER WITH THE SCRIPT 01b_MesobromionCluster.R







### PART 2 ####
source("01b_MesobromionCluster.R")
#### 1. Traits individually significant for COVER data#### na.exclude=T ########
traits <- read_delim("_data/Mesobromion/traits.v2.10perc.txt", delim="\t")
myfilelist <- list.files(path="_derived/Mesobromion/Cover/onebyone", pattern="HIDDENcov-nona2_[0-9]+_.RData", full.names = T)
dataFiles = purrr::map(myfilelist, function(x){get(load(x))})
corXY = bind_rows(dataFiles) %>% 
  as_tibble() %>% 
  distinct()
##find missing 
#missing <- gsub(pattern="_derived/Mesobromion/Cover/HIDDENcov-nona2_", replacement = "", x = myfilelist)
#missing <- gsub(pattern="_.RData", replacement = "", x = missing)
#missing <- sort(as.numeric(missing))
#which(!1:127 %in% missing)

rm( dataFiles)

trait.labs <- data.frame(Trait.comb=as.character(1:(ncol(traits)-1)), 
                         trait.name=colnames(traits)[-1]) 

corXY.ci <- get.ci(corXY)
corXY.ci <- corXY.ci %>% 
  arrange(desc(sign_plus), desc(Coef.obs)) %>% 
  left_join(trait.labs, by="Trait.comb") %>% 
  dplyr::select(-Test)

traits.sign.alone <- corXY.ci %>% 
  filter(sign_plus) %>% 
  pull(trait.name)

traits.sign <- traits %>% 
  dplyr::select(species0, any_of(traits.sign.alone))
write_delim(traits.sign, path="_data/Mesobromion/traits.v2.10perc.cov.sign.txt", delim="\t")

### COV - NONAs - NEW DATASET
"# A tibble: 49 x 11
   Trait.comb Coef.obs Coef.perm  q025  q975 greater.than.perm     n sign_plus sign_minus ntraits trait.name   
   <chr>         <dbl>     <dbl> <dbl> <dbl>             <dbl> <int> <lgl>     <lgl>        <int> <fct>        
 1 46            0.317    0.106  0.289 0.365             0.997   999 TRUE      FALSE            1 Leaf_Scleroph
 2 33            0.267    0.168  0.244 0.317             0.990   999 TRUE      FALSE            1 Height       
 3 29            0.251    0.206  0.231 0.300             0.976   999 TRUE      FALSE            1 SLA          
 4 2             0.250    0.111  0.218 0.296             0.988   999 TRUE      FALSE            1 GF_Nanophan  
 5 27            0.237    0.167  0.213 0.284             0.975   999 TRUE      FALSE            1 FP_Dur       
 6 30            0.212    0.125  0.192 0.260             0.953   999 TRUE      FALSE            1 LeafCdrymass 
 7 5             0.210    0.0489 0.176 0.267             0.977   999 TRUE      FALSE            1 GF_Hemiphan  
 8 17            0.207    0.123  0.166 0.273             0.965   999 TRUE      FALSE            1 VP_Fragm     
 9 32            0.214    0.0827 0.195 0.262             0.939   999 FALSE     FALSE            1 LeafP        
10 31            0.195    0.133  0.176 0.241             0.919   999 FALSE     FALSE            1 LeafN"

### COV - NONAs - old dataset - First selection of plots
"# A tibble: 48 x 11
   Trait.comb Coef.obs Coef.perm  q025  q975 greater.than.perm     n sign_plus sign_minus ntraits trait.name           
   <chr>         <dbl>     <dbl> <dbl> <dbl>             <dbl> <int> <lgl>     <lgl>        <int> <fct>                
 1 31            0.304    0.0805 0.280 0.357             0.994   999 TRUE      FALSE            1 PlantHeight          
 2 45            0.292    0.205  0.263 0.344             0.990   999 TRUE      FALSE            1 BL_ANAT              
 3 2             0.262    0.126  0.230 0.317             0.988   999 TRUE      FALSE            1 LEB_F_Nanophanerophyt
 4 25            0.259    0.125  0.227 0.307             0.974   999 TRUE      FALSE            1 BL_DAU               
 5 16            0.251    0.0718 0.204 0.326             0.983   999 TRUE      FALSE            1 V_VER_Fragmentation  
 6 27            0.247    0.0761 0.227 0.297             0.965   999 TRUE      FALSE            1 SLA                  
 7 30            0.241    0.207  0.213 0.286             0.951   999 TRUE      FALSE            1 LeafP                
 8 44            0.238    0.187  0.213 0.285             0.971   999 TRUE      FALSE            1 STRAT_T        "


#### 2. Traits individually significant for Presence|absence data####
traits <- read_delim("_data/Mesobromion/traits.v2.10perc.txt", delim="\t")
myfilelist <- list.files(path="_derived/Mesobromion/PresAbs/onebyone", pattern="HIDDENpa-nona2_[0-9]+_.RData", full.names = T)
dataFiles = purrr::map(myfilelist, function(x){get(load(x))})
corXY = bind_rows(dataFiles) %>% 
  as_tibble()
rm( dataFiles)

trait.labs <- data.frame(Trait.comb=as.character(1:(ncol(traits)-1)), 
                         trait.name=colnames(traits)[-1]) 

corXY.ci <- get.ci(corXY)
corXY.ci <- corXY.ci %>% 
  arrange(desc(sign_plus), desc(Coef.obs)) %>% 
  left_join(trait.labs, by="Trait.comb") %>% 
  dplyr::select(-Test)

traits.sign.alone <- corXY.ci %>% 
  filter(sign_plus) %>% 
  pull(trait.name)

traits.sign <- traits %>% 
  dplyr::select(species0, any_of(traits.sign.alone))
write_delim(traits.sign, path="_data/Mesobromion/traits.v2.10perc.pa.sign.txt", delim="\t")

## NONAs - New data
"# A tibble: 49 x 11
   Trait.comb Coef.obs Coef.perm  q025  q975 greater.than.perm     n sign_plus sign_minus ntraits trait.name    
   <chr>         <dbl>     <dbl> <dbl> <dbl>             <dbl> <int> <lgl>     <lgl>        <int> <fct>         
 1 46            0.326    0.190  0.297 0.376             0.999   999 TRUE      FALSE            1 Leaf_Scleroph 
 2 33            0.285    0.0765 0.256 0.334             0.997   999 TRUE      FALSE            1 Height        
 3 2             0.281    0.0683 0.250 0.329             0.998   999 TRUE      FALSE            1 GF_Nanophan   
 4 29            0.265    0.0748 0.243 0.311             0.990   999 TRUE      FALSE            1 SLA           
 5 30            0.254    0.105  0.227 0.306             0.988   999 TRUE      FALSE            1 LeafCdrymass  
 6 27            0.245    0.119  0.220 0.296             0.982   999 TRUE      FALSE            1 FP_Dur        
 7 5             0.245    0.131  0.213 0.303             0.986   999 TRUE      FALSE            1 GF_Hemiphan   
 8 31            0.235    0.0744 0.214 0.285             0.974   999 TRUE      FALSE            1 LeafN         
 9 32            0.231    0.189  0.204 0.283             0.976   999 TRUE      FALSE            1 LeafP         
10 35            0.207    0.0881 0.185 0.255             0.951   999 TRUE      FALSE            1 SeedLength    
11 1             0.191    0.0483 0.161 0.239             0.961   999 TRUE      FALSE            1 GF_Macrophan  
12 34            0.197    0.0669 0.179 0.244             0.948   999 FALSE     FALSE            1 SeedMass  "

## NONAs - Old data
"# A tibble: 48 x 11
   Trait.comb Coef.obs Coef.perm  q025  q975 greater.than.perm     n sign_plus sign_minus ntraits trait.name            
   <chr>         <dbl>     <dbl> <dbl> <dbl>             <dbl> <int> <lgl>     <lgl>        <int> <fct>                 
 1 45            0.311    0.139  0.282 0.364             0.999   999 TRUE      FALSE            1 BL_ANAT               
 2 31            0.307    0.160  0.279 0.358             0.999   999 TRUE      FALSE            1 PlantHeight           
 3 2             0.295    0.123  0.256 0.347             0.994   999 TRUE      FALSE            1 LEB_F_Nanophanerophyt 
 4 25            0.260    0.0982 0.231 0.307             0.983   999 TRUE      FALSE            1 BL_DAU                
 5 27            0.260    0.0963 0.237 0.305             0.984   999 TRUE      FALSE            1 SLA                   
 6 30            0.253    0.158  0.229 0.300             0.987   999 TRUE      FALSE            1 LeafP                 
 7 28            0.240    0.0705 0.212 0.295             0.980   999 TRUE      FALSE            1 LeafC.perdrymass      
 8 44            0.240    0.0618 0.213 0.293             0.981   999 TRUE      FALSE            1 STRAT_T               
 9 29            0.233    0.0978 0.210 0.285             0.966   999 TRUE      FALSE            1 LeafN                 
10 33            0.228    0.183  0.205 0.275             0.968   999 TRUE      FALSE            1 Seed.length           
11 34            0.226    0.0736 0.196 0.281             0.965   999 TRUE      FALSE            1 LDMC                  
12 5             0.226    0.113  0.190 0.283             0.975   999 TRUE      FALSE            1 LEB_F_Hemiphanerophyt 
13 40            0.209    0.128  0.185 0.259             0.957   999 TRUE      FALSE            1 Disp.unit.leng     "


